/**
 * 
 */
package de.mpc.prolic.model;

import java.util.ArrayList;

/**
 * Represents basic features of an enzyme used for digestion of a protein.
 * @author Michael Kohl
 */
public class Enzyme {

	/*******************************************************************************
	 * Members
	 ******************************************************************************/	
	private String enzymeName;							//The name of this enzyme
	private ArrayList<CleavageSite> cleavageSites;
	private boolean performsN_terminalCleavage;			//Specifies whether the enzyme cleaves in the N-terminal (==true) or the C-terminal(==false) direction.
	private String regExDigestion;	 					/*The regular expression used to determine in silicio digested peptides
														This is used in particular to calculate the C- and/or the N- terminal peptide */
	
	/**
	 * Empty constructor
	 */
	public Enzyme() {
		cleavageSites = new ArrayList<CleavageSite>();
	}
	
	public void addCleavageSite(CleavageSite cs){
		this.cleavageSites.add(cs);
	}
	
	/**
	 * The method checks whether the enzyme has a specific cleavage site
	 * @param c_
	 */
	public boolean checkCleavageSite(char c_){
		boolean hasThisCleavageSite=false;
		char enzymeCS;
		for(int i=0;i<cleavageSites.size();i++){
			enzymeCS=cleavageSites.get(i).getAa_site();
			if(c_==enzymeCS){
				hasThisCleavageSite=true;
			}
		}
		return hasThisCleavageSite;
	}
	
	/*******************************************************************************
	 * Setter and Getter
	 ******************************************************************************/
	public ArrayList<CleavageSite> getCleavageSites(){
		return this.cleavageSites;
	}
	
	
	public void setRegExDigestion(String regExDigestion_){
		this.regExDigestion=regExDigestion_;
	}
	
	public String getRegExDigestion(){
		return this.regExDigestion;
	}
	
	public void setEnzymeName(String enzymeName_){
		this.enzymeName=enzymeName_;
	}
	
	public String getEnzymeName(){
		return this.enzymeName;
	}
	
	public void setPerformsN_terminalCleavage(boolean performsN_terminalCleavage_){
		this.performsN_terminalCleavage=performsN_terminalCleavage_;
	}
	
	public boolean getPerformsN_terminalCleavage(){
		return this.performsN_terminalCleavage;
	}
	
}
