/**
 * 
 */
package de.mpc.prolic.model;

import java.util.ArrayList;

/**
 * Representation of a Transcript (i.e. the processed messenger mRNA that arise from the precursor mRNA). A Transcript instance is related to a Gene instance  
 * This class is designed for future versions of ProLiC that consider also gene information and is currently not in use.
 * @author Michael Kohl
 *
 */
public class Transcript extends Biomolecule {

	/*******************************************************************************
	 * Members
	 ******************************************************************************/	
	private Gene relatedGene;	 				//Each Transcript has a reference to its origin, i.e the gene, which is inferred for this transcript. 
	private ArrayList<Probe> probes;			/*The Probe set that is measured in a microarray experiment in order to compute expression data for a
												related Transcript.*/
	/*******************************************************************************
	 * Constructors
	 ******************************************************************************/
	/**
	 * Empty Constructor
	 */
	public Transcript() {

	}
	
	/**
	 * @param sequence_
	 */
	public Transcript(String sequence_) {
		super(sequence_);
	}

	/**
	 * @param sequence_
	 * @param origin_
	 */
	public Transcript(String sequence_, String origin_) {
		super(sequence_, origin_);
	}
	
	/*******************************************************************************
	 * Setter and Getter
	 ******************************************************************************/
	public Gene getRelatedGene(){
		return relatedGene;
	}
	
	public void setRelatedProt(Gene relatedGene_){
		relatedGene = relatedGene_;
	}

	public ArrayList<Probe> getProbes(){
		return probes;
	}
	
	public void setProbes(ArrayList<Probe> probes_){
		probes = probes_;
	}
}
